;;;;;;;;;;;;;;;;;;;;;;;;;;;;;<--OGI-->;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                        ;;
;;             Center for Spoken Language Understanding                   ;;
;;        Oregon Graduate Institute of Science & Technology               ;;
;;                         Portland, OR USA                               ;;
;;                        Copyright (c) 1999                              ;;
;;                                                                        ;;
;;      This module is not part of the CSTR/University of Edinburgh       ;;
;;               release of the Festival TTS system.                      ;;
;;                                                                        ;;
;;  In addition to any conditions disclaimers below, please see the file  ;;
;;  "license_ogi_tts.txt" distributed with this software for information  ;;
;;  on usage and redistribution, and for a DISCLAIMER OF ALL WARRANTIES.  ;;
;;                                                                        ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;<--OGI-->;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                       ;;
;;                Center for Spoken Language Understanding               ;;
;;                     Oregon Graduate Institute                         ;;
;;                         Copyright (c) 1998                            ;;
;;                        All Rights Reserved.                           ;;
;;                                                                       ;;
;;  Permission to use, copy, modify, distribute this software and its    ;;
;;  documentation for research, educational and individual use only, is  ;;
;;  hereby granted without fee, subject to the following conditions:     ;;
;;   1. The code must retain the above copyright notice, this list of    ;;
;;      conditions and the following disclaimer.                         ;;
;;   2. Any modifications must be clearly marked as such.                ;;
;;   3. Original authors' names are not deleted.                         ;;
;;  This software may not be used for commercial purposes without        ;;
;;  specific prior written permission from the authors.                  ;;
;;                                                                       ;;
;;  OREGON GRADUTE INSTITUTE AND THE CONTRIBUTORS TO THIS WORK           ;;
;;  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING      ;;
;;  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT   ;;
;;  SHALL OREGON GRADUATE INSTITUTE NOR THE CONTRIBUTORS BE LIABLE       ;;
;;  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES    ;;
;;  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN   ;;
;;  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,          ;;
;;  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF       ;;
;;  THIS SOFTWARE.                                                       ;;
;;                                                                       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                       ;;
;;       A German Voice for the Festival Speech Synthesis System         ;;
;;        Authors: Karin Mueller, Bettina Saeuberlich, Horst Meyer,      ;;
;;                 Mike Macon and Alan W Black                           ;;
;;          Date:  OGI, June/July 1998                                   ;;
;;                                                                       ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(defvar axk_diphone_dir (cdr (assoc 'axk_diphone voice-locations))
  "axk_diphone_dir
  The default directory for the axk diphone database.")


;; for german text pre-processing
(set! load-path (cons (path-append libdir "german/") load-path))

;; for other stuff
(set! load-path (cons (path-append libdir "ogi_german/") load-path))

;; only for building the voice
(set! bcs_diphone_src_dir "/home/macon/german/bcs")

(require 'ims_german_preproc)
(require 'german-sampa_phones)
(require 'map-de)
(require 'de-pos)
(require 'de-lex)
(require 'dtoken)
(require 'deduration)
(require 'german_postlex)  
(require 'de-intro)
(require 'ogi_unitsel)
(require 'ogi_synthesis)
 
;;; Use the grouped file by default
(defvar axkdi_grouped_or_ungrouped 'grouped)

;;;  Full voice definition 
(define (voice_axk_diphone)
"(voice_axk_diphone)
Set up synthesis for male German speaker: using OGIresLPC synth"

  (voice_reset)

  (Parameter.set 'Language 'german)
  ;; Phone set
  (Parameter.set 'PhoneSet 'german-sampa)
  (PhoneSet.select 'german-sampa)
  ;; Tokenization
  (Parameter.set 'Token_Method 'Token_Any)
  (set! token_to_words german_token_to_words)
  ;; No pos prediction (get it from lexicon)
  (set! pos_lex_name nil)
  ;; Phrase break prediction by punctuation
  (set! pos_supported nil) ;; well not real pos anyhow
  (set! guess_pos german_guess_pos)   ;; need this for accents
  ;; Phrasing
  (set! phrase_cart_tree simple_phrase_cart_tree)
  (Parameter.set 'Phrase_Method 'cart_tree)
  ;; Lexicon selection
  (lex.select "german-pre")
  ;; Accent and tone prediction
  (set! int_accent_cart_tree simple_accent_cart_tree)
  (require 'f2bf0lr)
  (set! f0_lr_start f2b_f0_lr_start)
  (set! f0_lr_mid f2b_f0_lr_mid)
  (set! f0_lr_end f2b_f0_lr_end)
  (Parameter.set 'Int_Method Intonation_Tree)
  (set! int_lr_params
	'((target_f0_mean 120) (target_f0_std 16)
	  (model_f0_mean 170) (model_f0_std 34)))
  (Parameter.set 'Int_Target_Method Int_Targets_LR)
  ;; Duration prediction
  (set! duration_cart_tree de_gsw_duration_cart_tree)
  (set! duration_ph_info german_phone_data)
  (Parameter.set 'Duration_Method 'Tree_ZScores)

  ;; diphone unit selection fallbacks
  (set! ogi_di_alt_L '((x (C)) (C (x)) (b (p)) (g (k)) (d (t)) (v (f)) (? (_)) (h (_))))
  (set! ogi_di_alt_R '((x (C)) (C (x)) (b (p)) (g (k)) (d (t)) (v (f)) (? (_)) (h (_))))
  (set! ogi_di_default "pau-h")

  ;; Postlexical rules
  (set! postlex_rules_hooks 
	(list Stop_before_Vowel Stop_after_Prefix))

  ;; Waveform synthesizer: diphones
  (Parameter.set 'Synth_Method 'OGIdiphone)
  (OGIdbase.activate "axk_diphone")      
  (OGIresLPC.init axkdi_OGI_syn_params)  
  (set! current-voice 'axk_diphone)  
  )

(set! axkdi_smooth_spectra   ;;; max number of frames to use in smoothing LPC at joins
      '(spectra_smooth
        ((vc + 5)   ; vowel
         (ctype s 0) ; stop
         (ctype f 2) ; fricative
         (ctype a 0) ; affricate
         (ctype n 4) ; nasal
         (ctype l 4) ; lateral
         (ctype r 4) ; approximant
         )))
 
(set! axkdi_smooth_power   ;;; max number of frames to use in smoothing power at joins
      '(power_smooth
        ((vc + 10)   ; vowel
         (ctype s 0) ; stop
         (ctype f 2) ; fricative
         (ctype a 0) ; affricate
         (ctype n 5) ; nasal
         (ctype l 5) ; lateral
         (ctype r 5) ; approximant 
         )))
 
;;
;;  Residual LPC synthesizer parameters - used by OGIresLPC.init
;;
(set! axkdi_OGI_syn_params  
 (list
  '(F0_default 50.0)      ;; default Fo used if can't find any Fo targets
  '(T0_UV_thresh 0.020)   ;; used to make V/UV decision 
  '(T0_UV_pm 0.010)       ;; used to place UV pmarks
  '(post_gain 1.0)        ;; adjust final loudness
  '(deemphasis 0.94)      ;; opposite of preemphasis (lowpass filter)
  '(mod_method "direct")  ;; method for realizing prosodic targets
;  '(mod_method "none")  ;; method for realizing prosodic targets
  '(beta_smooth 5)        ;; smoother len for pitch mod factor in "soft" mod method
  '(smooth_cross_ph_join "Y") ;; smooth across joins at phone boundaries?
  '(window_type "trapezoid") 
  '(spectra_match_or_replace "match") ;; for join smoothing
  '(power_match_or_replace   "match") ;; for join smoothing
  axkdi_smooth_spectra
  axkdi_smooth_power
  ))
 
 
(define (init_axk_diphone)
"(init_axk_diphone)
  Initialise the AXK diphone database.  This sets up the 16K version
  for residual excited LPC."
(if (equal? axkdi_grouped_or_ungrouped 'ungrouped)
 
    ;;  ungrouped
    (OGIdbase.init
     (list
      '(dbname axk_diphone)
      (list 'unitdic_file (path-append axk_diphone_dir "festvox" "axkdiph.msec"))
;      (list 'gain_file (path-append axk_diphone_dir "festvox" "axkgain.dat"))
      '(phoneset "sampa")  
      '(base_dir "/u/macon/TTS/tts_data/axk/")
      '(lpc_dir "lpc16/")
      '(lpc_ext ".lpc")
      '(exc_dir "lpc16/")
      '(exc_ext ".res")
      '(pm_dir "pm/")
      '(pm_ext ".pmv")
      '(data_type "resLPC")
      '(access_mode "ondemand")
      '(samp_freq 16000)
      '(sig_band 0.010)
      '(isCompressed "Y") ;; if "Y", compress when saving group file
      '(preemph 0.96)  
      ))
 
    ;;  grouped -- parameters set here override those in groupfile
    (OGIdbase.init   
     (list
      '(dbname axk_diphone)
      (list 'groupfile (path-append axk_diphone_dir "group" "axk_di_resLPC.group"))
      '(access_mode "ondemand")
      ))
    t)
)

(init_axk_diphone)
 
 
(proclaim_voice
 'axk_diphone
 '((language german)
   (gender male)
   (dialect berlin+usa)
   (description
    "  This voice provides a German female using a
     residual excited LPC diphone synthesis module created at
     OGI, summer 1998.  
       Diese Festival Version wurde fuer das Deutsche, an dem Oregon
     Graduierten Institut von Karin Mueller, Bettina Saeuberlich, Horst
     Meyer, Alan Black, und Mike Macon entwickelt.")))

(provide 'axk_diphone)



